@@ -3,20 +3,21 @@
 
     Copyright (c) 1999 - 2002 Chris Schlaeger <cs@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License version 2 or at your option version 3 as published by
-    the Free Software Foundation.
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License or (at your option) version 3 or any later version
+ accepted by the membership of KDE e.V. (or its successor approved
+ by the membership of KDE e.V.), which shall act as a proxy 
+ defined in Section 14 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <kacceleratormanager.h>
@@ -26,26 +27,36 @@
 
 #include <QGroupBox>
 #include <QLabel>
-#include <QLayout>
-#include <QSpinBox>
-
+#include <QGridLayout>
+#include <QVBoxLayout>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 #include "WorkSheetSettings.h"
 
 WorkSheetSettings::WorkSheetSettings( QWidget* parent, bool locked )
-  : KDialog( parent )
+  : QDialog( parent )
 {
   setObjectName( "WorkSheetSettings" );
   setModal( true );
-  setCaption( i18n( "Tab Properties" ) );
-  setButtons( Ok | Cancel );
+  setWindowTitle( i18n( "Tab Properties" ) );
+  QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+  QVBoxLayout *mainLayout = new QVBoxLayout;
+  setLayout(mainLayout);
+  QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+  okButton->setDefault(true);
+  okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+  connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+  connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
   QWidget *page = new QWidget( this );
-  setMainWidget( page );
+  mainLayout->addWidget(page);
+  mainLayout->addWidget(buttonBox);
 
   QVBoxLayout *topLayout = new QVBoxLayout( page );
   topLayout->setMargin( 0 );
-  topLayout->setSpacing( spacingHint() );
+  //PORT QT5 topLayout->setSpacing( spacingHint() );
 
   QGroupBox *group = new QGroupBox( i18n( "Title" ), page );
 
@@ -151,4 +162,4 @@ QString WorkSheetSettings::sheetTitle() const
   return mSheetTitle->text();
 }
 
-#include "WorkSheetSettings.moc"
+
